Monty Python's Flying Circus: Just the Words - Episode 31

# Episode Thirty-one: The All-England Summarize Proust Competition

'Summarize Proust Competition'
Everest climbed by hairdressers
Fire brigade
Our Eamonn
'Party Hints' with Veronica Smalls
Language laboratory
Travel agent
Watney's Red Barrel
Theory on Brontosauruses by Anne Elk (Miss)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Nude man at the organ plays chords.
Announcer | And now...
It's Man | It's...
| Animated titles.
Voice Over | Monty Python's Flying Circuses...
| The hall of the Memorial Baths, Swansea, done up for a gala occasion. There is a stage with flags, bunting and flowers. Echoing noise of audience anticipation. Muffled tannoy announcements in background.
Voice Over | Good evening, and welcome to the Arthur Ludlow Memorial Baths, Newport, for this year's finals of the All-England Summarize Proust Competition. (pull back slightly to reveal big banner across the top of the stage: 'All-England Summarize Proust Competition') As you may remember, each contestant has to give a brief summary of Proust's 'A La Recherche du Temps Perdu', once in a swimsuit and once in evening dress. The field has now narrowed to three finalists and your judges tonight are... (cut to panel of judges at long desk; they are all cut-outs of smiling photos of the following) Alec and Eric Bedser, ex-Surrey cricketers, Stewart Surridge, ex-captain of Surrey, Omar Sharif, Laurie Fishlock, ex-Surrey opening batsman, Peter May, the former Surrey and England Captain, and Yehudi Menuhin, the world-famous violinist and the President of the Surrey Cricket Club. And right now it's time to meet your host for tonight Arthur Mee!
| Showbiz music, applause, and Arthur Mee appears from the back of the stage; he wears the now traditional spangly jacket. He comes forward and speaks into the mike (the sound is rather hollow and strident as in big halls with a hastily rigged PA).
Mee | Good evening and welcome, whereas Proust would say, 'la malade imaginaire de recondition et de toute surveillance est bientôt la même chose'. (roars of applause; quick shot of grinning faces of the jury) Remember each contestant this evening has a maximum of fifteen seconds to sum up 'A La Recherche du Temps Perdu' and on the Proustometer over here... (curtain pulls back at back of stage to reveal a true, enormous, but cheap, audience appreciation gauge; it lists the seven books of Proust's masterwork in the form of a thermometer) you can see exactly how far he gets. So let's crack straight on with our first contestant tonight. He's last year's semi-finalist from Luton - Mr Harry Bagot. (Harry Bagot, in evening dress, comes forward from back of stage, he has a number three on his back; Mee leads the applause for him) Hello Harry. Now there's the summarizing spot you're on the summarizing spot, fifteen seconds from now.
| Music starts, continuity-type music. The needle of the Proustometer creeps up almost inperceptibly to a tiny level.
Harry | Proust's novel ostensibly tells of the irrevocability of time lost, the forfeiture of innocence through experience, the reinstallment of extra-temporal values of time regained, ultimately the novel is both optimistic and set within the context of a humane religious experience, re-stating as it does the concept of intemporality. In the first volume, Swarm, the family friend visits...
| Gong goes, chord of music, applause. The meter has hardly risen at all.
Mee | Well tried, Harry.
Voice Over | A good attempt there but unfortunately he chose a general appraisal of the work, before getting on to the story and as you can see (close up of Proustometer) he only got as far as page one of 'Swarm's Way', the first of the seven volumes. A good try though and very nice posture.
| Cut back to the stage.
Mee | Harry Bagot, you're from Luton?
Harry | Yes, Arthur, yeah.
Mee | Now Harry what made you first want to try and start summarizing Proust?
Harry | Well I first entered a seaside Summarizing Proust Competition when I was on holiday in Bournemouth, and my doctor encouraged me with it.
Mee | And Harry, what are your hobbies outside summarizing?
Harry | Well, strangling animals, golf and masturbating.
Mee | Well, thank you Harry Bagot.
| Harry walks off-stage. Music and applause.
Voice Over | Well there he goes. Harry Bagot. He must have let himself down a bit on the hobbies, golf's not very popular around here, but never mind, a good try.
Mee | Thank you ladies and gentlemen. Mr Rutherford from Leicester, are you ready Ronald? (Ronald is a very eager man in tails) Right. On the summarizing spot. You have got fifteen seconds from now.
Ronald | Er, well, Swann, Swann, there's this house, there's this house, and er, it's in the morning, it's in the morning - no, it's the evening, in the evening and er, there's a garden and er, this bloke comes in - bloke comes in - what's his name - what's his name, er just said it - big bloke - Swann, Swann
| The gong sounds. Mee pushes Ronald out.
Mee | And now ladies and gentlemen, I'd like you to welcome the last of our all-England finalists this evening, from Bingley, the Bolton Choral Society and their leader Superintendent McGough, (a big choir comes on, immaculately drilled, each holding a score, with Fred Tomlinson as superintendent McGough) All right Bingley, remember you've got fifteen seconds to summarize Proust in his entirety starting from now.
First Soloist | Proust, in his first book wrote about... fa la la...
Second Soloist | Proust in his first book wrote about...
Tenors | He wrote about...
| They continue contrapuntally, in madrigal, never getting beyond these words until they rallentando to say...
All | Proust in his first book wrote about the... (gong sounds)
Voice Over | Very ambitious try there, but in fact the least successful of the evening, they didn't even get as far as the first volume. (the singers leave the stage)
Mee | Well ladies and gentlemen, I don't think any of our contestants this evening have succeeded in encapsulating the intricacies of Proust's masterwork, so I'm going to award the first prize this evening to the girl with the biggest tits.
| Applause and music. A lady with enormous knockers comes on to the side of the stage. Roll credits:
| THE ALL-ENGLAND SUMMARIZE PROUST COMPETITION A BBC PRODUCTION WITH MR I. T. BRIDDOCK, 2379, THE TERRACE, HODDESDON. IT WAS CONCEIVED, WRITTEN AND PERFORMED BY...
| Roll usual Monty Python credits and music. Behind them the lady accepts the cup and the singers come back on stage and admire her. Fade out. Slight pause. Fade up on stock film of Everest. Whistling wind, stirring music.
Voice Over | Mount Everest. Forbidding. Aloof. Terrifying. The mountain with the biggest tits in the world.
| Sound of gong.
Second Voice Over | Start again!
| A very silly loony leans into shot, on overlay (i.e. in front of the picture), and waves to the camera. He goes out of shot again.
Voice Over | Mount Everest. Forbidding. Aloof. Terrifying. This year, this remote Himalayan mountain, this mystical temple, surrounded by the most difficult terrain in the world, repulsed yet another attempt to conquer it. This time, by the International Hairdresser's Expedition. (cut to shot of pup tent in blizzard) In such freezing, adverse conditions, man comes very close to breaking point. What was the real cause of the disharmony which destroyed their chances at success?
| Cut to three head-and-shoulders shots. They look like typical mountaineers: frost in their beards, tanned, with snow glasses on their foreheads and authentic Everest headgear.
First Climber | Well, people would keep taking my hairdryer and never returning it.
Second Climber | There was a lot of bitching in the tents.
Third Climber | You couldn't get near the mirror.
| Cut to a colonel figure, digging in a garden in Jersey.
Voice Over | The leader of the expedition was Colonel Sir John 'Teasy-Weasy' Butler, veteran of K2, Annapurna, and Vidals. His plan was to ignore the usual route around the South Col and to make straight for the top.
| Cut to a photo of Everest with dots superimposed, showing the route.
Colonel | We established base salon here, (on the photos, we see the words 'base salon') and climbed quite steadily up to Mario's here. (at the top of the route we see 'Mario's') From here using crampons and cutting ice steps as we went, we moved steadily up the Lhotse Face to the North Ridge, establishing camp three where we could get a hot meal, a manicure, and a shampoo and set.
| Cut to stock film of people actually climbing Everest.
Voice Over | Could it work? Could this eighteen-year old hairdresser from Brixton succeed where others had failed? The situation was complicated by the imminent arrival of the monsoon storms. Patrice takes up the story.
| Cut to interior of hairdresser's salon. Patrice speaks into the mirror, as he is blow-drying and curling a lady's hair.
Patrice | Well, we knew as well as anyone that the monsoons were due, but the thing was, Ricky and I had just had a blow dry and rinse, and we couldn't go out for a couple of days.
| Cut to stock film of some people leaving a little tent on a mountain.
Voice Over | After a blazing row, the Germans and Italians had turned back, taking with them the last of the hair nets. On the third day a blizzard blew up. (close up on the tent in a blizzard; no people in shot) Temperatures fell to minus thirty centigrade. Inside the little tent, things were getting desperate.
| We cut inside the tent. The wind is banging against the side of the material, sounds of a vicious blizzard. Ricky is sitting next to another member of the expedition. Both are under hairdryers, in full climbing gear up to their necks. One is reading Vogue. Ricky is doing his nails.
Ricky | Well, things have got so bad that we've been forced to use the last of the heavy oxygen equipment just to keep the dryers going.
Woman | (off-screen) Cup of Milo, love.
Ricky | Oh, she's a treas. (he takes the drink)
| Cut to a wide shot of Everest.
Voice Over | But a new factor had entered the race. A team of French chiropodists, working with brand new cornplasters and Doctor Scholl's Mountaineering Sandals, were covering ground fast. The Glasgow Orpheus Male Voice Choir were tackling the difficult North Col. (quick cut to film of lots of people climbing up Everest; dubbed over is the 'Proust' song as in 'Proust Competition' item) Altogether, fourteen expeditions (cut to a diagram with hundreds of dotted lines over it, fourteen different routes) were at his heels. This was it. Ricky had to make a decision.
| Cut back to Patrice in the salon.
Patrice | Well, he decided to open a salon.
Voice Over | It was a tremendous success.
| Cinema-style adverts with still photos.
Advert Voice | Challenging Everest? Why not drop in at Ricky Pules' - only 24,000 feet from this cinema. Ricky and Maurice offer a variety of styles for the well-groomed climber. Like Sherpa Tensing and Sir Edmond Hillary be number one on top, when you're Number One on Top? (just their heads turn to show off the hair-do)
| Animated sketch leads to little old Mrs Little on the phone in her hall. She is a dear little old lady and lives in a rather fussy ducks-on-wall house.
Mrs Little | Hello, is that the fire brigade?
| Cut to the fire station.
First Fireman | No, sorry, wrong number.
| He puts the phone back. Pull out to reveal four or five firemen in full gear, surrounded by fire-fighting equipment and a gleaming fire engine. The firemen are engaged in a variety of homely pursuits: one is soldering a crystal set, another is cooking at a workbench, another is doing embroidery, another is at a sewing machine. The first fireman is at the phone on the wall. He goes back to clearing up a budgie's cage.
Second Fireman | That phone's not stopped ringing all day.
Third Fireman | What happens when you've mixed the batter, do you dice the ham with the coriander?
First Fireman | No, no, you put them in separately when the vine leaves are ready.
| The phone rings.
Second Fireman | Oh, no, not again.
Third Fireman | Take it off the hook.
| The first fireman takes the phone off the hook. Cut back to Mrs Little on phone. She looks at the receiver then listens again.
Mrs Little | I can't get the fire brigade Mervyn.
| Mervyn, her 38-year-old, 6' 8" son appears.
Mervyn | Here, let me try, dear. You go and play the cello.
Mrs Little | Oh it doesn't do any good, dear.
Mervyn | Look. Do you want the little hamster to live or not?
Mrs Little | Yes I do, Mervyn.
Mervyn | Well go and play the cello!
| She looks helplessly at him, then goes into the sitting room. Mervyn dials.
Mervyn | Hello, hello, operator? Yes we're trying to get the fire brigade ... No, the fire brigade. Yes, yes, yes, yes, yes, yes, yes, yes, yes, yes, what? ... (he takes one of his shoes off and looks in it) Size eight. Yes, yes, yes, yes, yes, yes, no of course not, Yes...
| Mrs Little appears, dabbing at her eyes with a handkerchief.
Mrs Little | (touching Mervyn gently on the arm) He's gone, dear.
Mervyn | What?
Mrs Little | He's slipped away.
Mervyn | What?
Mrs Little | The sodding hamster's dead!
Mervyn | (broken) Oh no!! What were you playing?
Mrs Little | Some Mozart concertos, dear.
Mervyn | What... How did he... ?
Mrs Little | His eyes just closed, and he fell into the wastepaper basket. I've covered him with a copy of the 'Charlie George Football Book'.
Mervyn | (handing her the phone) Right, you hang on. I must go and see him.
Mrs Little | There was nothing we could do, Mervyn. If we'd have had the whole Philharmonic Orchestra in there, he'd still have gone.
Mervyn | I'm going upstairs, I can't bear it.
Mrs Little | (restraining him) There isn't an upstairs dear, it's a bungalow.
Mervyn | Damn. (he storms off)
Mrs Little | (into the phone) Hello, I'm sorry to keep you waiting, It's just that... (she takes her shoe off and looks inside) size three, yes it's just - we've lost a dear one and my son was ... yes, that's right, size eight, yes and... Oh I see... yes, yes, yes, yes, yes, I see, yes, yes, I, I ... Yes, yes. No ... no... yes, I see. They can't get the fire brigade Mervyn - will the Boys' Brigade do?
Mervyn | (off) No! They'd be useless!
Mrs Little | No, he doesn't want anyone at the moment, thank you. No, yes, yes, no thank you for trying, yes, yes, ... no, Saxones, yes, yes thank you, bye, bye.
| As she puts the phone down the front door beside her opens and there stands a huge African warrior in war paint and with a spear and shield. At his feet are several smart suitcases.
Eamonn | Mummy!
Mrs Little | Eamonn. (he brings in the cases and closes the front door) Mervyn! Look it's our Eamonn - oh let me look at you, tell me how... how is it in Dublin?
Eamonn | Well, things is pretty bad there at the moment but there does seem some hope of a constitutional settlement.
Mrs Little | Oh don't talk. Let me just look at you.
Eamonn | Great to be home, mummy. How are you?
Mrs Little | Oh, I'm fine. I must just go upstairs and get your room ready.
Eamonn | It's a bungalow, mummy.
Mrs Little | Oh damn, yes. Mervyn, Mervyn - look who's here, it's our Eamonn come back to see us.
| Mervyn appears. He still looks shattered by the death of the hamster.
Mervyn | Hello, Eamonn.
Eamonn | Hello, Merv.
Mervyn | How was Dublin?
Eamonn | Well as I was telling mummy here, things is pretty bad there at the moment but there does seem some hope of a constitutional settlement.
| The phone rings.
Mervyn | (answering phone) Hello, yes, yes, yes, yes, yes - what? what? ... (looking at Eamonn's bare foot) Size seven. Yes, yes, yes, yes, yes .... it's the fire brigade, they want to know if they can come round Thursday evening.
Mrs Little | Oh no, Thursday's the Industrial Relations Bill Dinner Dance. Can't they make it another day?
Mervyn | (into the phone) Hello, no Thursday's right out. Yes, yes, yes, yes... (fade out)
| Fade up on a dinner-jacketed announcer sitting at a table with a bowl of flowers on it. A hand waves from inside the bowl of flowers.
Announcer | And so it was the fire brigade eventually came round on Friday night.
| Cut to fire engines skidding out of the fire station and roaring away - speeded up. They skid to a halt outside the Littles' suburban house. Firemen pour out of the fire engine and start to swarm in through the windows. Cut to interior of Littles' sitting room. It is laid out for a cocktail party. Mervyn is in evening dress and is sitting on the sofa looking very depressed. Mrs Little in a faded cocktail dress. Eamonn still in warpaint with spear and shield. The firemen appear.
Mrs Little | Oh, so glad you could come. What would you like to drink? Gin and tonic? Sherry?
Firemen | (in unison) A drop of sherry would be lovely. (as she starts to pour drinks the firemen confide in unison) We do like being called out to these little parties, they're much better than fires.
| The phone rings. Half the firemen go to answer it.
A Fireman | (off) Yes, yes yes.
Firemen | Well, how was Dublin, Eamonn?
Eamonn | Well, as I was telling mummy and Mervyn earlier, things is pretty bad there at the moment but there does seem some hope of a constitutional...
Mrs Little | (to camera) Look at them enjoying themselves. (shot of party in the hall; we can just see the fireman on phone; they keep looking at their shoe sizes) You know I used to dread parties until I watched 'Party Hints by Veronica'. I think it's on now...
| Panning shot across mountains in CinemaScope format.
| SUPERIMPOSED ROLLER CAPTION:
| THE BRITISH BROADCASTING CORPORATION IN ASSOCIATION WITH TRANSWORLD INTERNATIONAL AND NIMROD PRODUCTIONS PRESENT AN ARTHUR E. RICEBACHER AND DAVID A. SELTZER PRODUCTION FOR HASBACH ENTERPRISES OF CHARLES D. ORTIZ' ADAPTATION OF THE PULITZER PRIZEWINNING IDEA BY DANIEL E. STOLLMEYER BROUGHT TO THE SCREEN FROM ROBERT HUGHES'S NOVEL BY LOUIS H. TANNHAUSER AND VERNON D. LARUE PARTY HINTS BY VERONICA SMALLS A SELZENBACH-TANSROD PRODUCTION IN ASSOCIATION WITH VICTOR A. LOUNGE ROLO NICE SWEETIES FISON'S FERTILIZERS TIME LIFE INNIT-FOR-THE-MONEY LIMITED THE TRUSTEES OF ST PAUL'S CATHEDRAL THAT NICE MR ROBINSON AT THE VET'S RALPH READER RALPH NADER THE CHINESE GOVERNMENT MICHAEL'S AUNTIE BETTY IN AUSTRALIA A CINEMASCOPE PRODUCTION
| Cut to Veronica in the 'Party Hints' set - a chintzy kitchen.
Veronica | Hello, Last week on 'Party Hints' I showed you how to make a small plate of goulash go round twenty-six people, how to get the best out of your canapés, and how to unblock your loo. This week I'm going to tell you what to do if there is an armed communist uprising near your home when you're having a party. Well obviously it'll depend how far you've got with your party when the signal for Red Revolt is raised. If you're just having preliminary aperitifs - Dubonnet, a sherry or a sparkling white wine - then the guests will obviously be in a fairly formal mood and it will be difficult to tell which are the communist agitators. So the thing to do is to get some cloth and some bits of old paper, put it down on the floor and shoot everybody. This will deal with the Red Menace on your own doorstep. If you're having canapés, as I showed you last week, or an outdoor barbecue, then the thing to do is to set fire to all houses in the street. This will stir up anti-communist hatred and your neighbours will be right with you as you organize counter-revolutionary terror. So you see, if you act promptly enough, any left-wing uprising can be dealt with by the end of the party. Bye...
| ANIMATION: one dozen communist revolutions.
| Then cut to a language laboratory. Mr Mann is showing Tick round. There is a line of booths, each lined with pegboard. Each has a person with a pair of earphones on with attached microphones, a tape recorder and a swivel chair.
First Booth | Bleck people. Bleck people. Rrrhodesian. Kill the blecks. Rrhodesian. Smith, Smith. Kill the blecks within the five principles.
| He starts to rewind the tape recorder. Nods at Mr Mann. They come to the second booth.
Second Booth | I'm afraid I cannot comment on that until it's been officially hushed up.
Mr Mann | This is our politicians booth.
Second Booth | While there is no undue cause for concern, there is certainly no room for complacency. Ha, ha, ha. He, he, he.
| They pass on to the next booth.
Third Booth | Well I'll go, I'll go to the foot of our stairs. Ee ecky thump. Put wood in 'ole, muther.
| Mr Mann taps him. He removes his earphones.
Third Booth | (normal) Yes?
Mr Mann | Ee ecky thump.
Third Booth | (trying it) Ee ecky thump.
Mr Mann | Ee ecky thump! (indicates more power)
Third Booth | Ee ecky thump!
Mr Mann | Excellent.
Third Booth | Thank you, sir. (puts earphones on, listens)
Mr Mann | It's a really quick method of learning.
Third Booth | Can you smell gas or is it me?
Tick | (who is very diffident) Looks jolly good.
| They come to the fourth booth where sits a very city-type gent.
Fourth Booth | Hello, big boy. (very breathy) Oo varda the ome. D'you want a nice time?
Mr Mann | Very good.
Fourth Booth | (butch) Thank you very much, sir.
| They pass the fifth booth, whose occupant is making silly noises.
Mr Mann | And we control everything from here. (indicating the control desk)
Tick | Superb.
Mr Mann | Well then what sort of thing were you looking for?
Tick | Well, er, really something to make me a little less insignificant?
Mr Mann | Oh, I see sort of 'Now look here, you may be Chairman but your bloody pusillanimous behaviour makes me vomit!' That sort of thing?...
Tick | Oh no, no, no, not really no.
Mr Mann | Oh I see, well perhaps something a bit more sort of Clive Jenkins-ish? Perhaps - sort of (Welsh accent) 'Mr Smarmy so-called Harold Wilson can call himself pragmatic until he's blue in the breasts'.
Tick | Oh no, I really want something that will make people be attracted to me like a magnet.
Mr Mann | I see, well, you want our 'Life and Soul of the Party' tape then, I think.
Tick | What's that?
Mr Mann | Well it's sort of 'Ello squire, haven't seen you for a bit, haven't seen you for a bit either, Beryl. Two pints of wallop please, love. Still driving the Jensen then? Cheer up Jack it may never happen, what's your poison then?'
Tick | Fantastic, yes.
Mr Mann | Right, I'll just see if we've got the tape.
| He puts the headphones on. Whilst he looks away, the whole of the back wall of people in booths, swing round on their chairs and do a little thirties routine, with their earphones on, kicking their legs, etc., they sing.
| SUPERIMPOSED CAPTION: 'SANDY WILSON'S VERSION OF "THE DEVILS" '
All | Boo boopee doo Boo boopee doo Scuby duby duby doo-oo! Hello operator Is that the central line Give me the Piccadilly number Nine one o nine Mr operator now that number's wrong So come on everybody Let's sing this song... ... Prouse in his first book wrote about... etc ....
| Gong sounds.
Voice Over | Start again.
| The loony leans into shot and waves. Fade to black. Fade up on close up of picture of Everest. Pull back to reveal travel agent's office.
Bounder | Mount Everest, forbidding, aloof, terrifyring. The highest place on earth. No I'm sorry we don't go there. No.
| By the time Bounder is saying his last sentence the camera has revealed the office and Bounder himself sitting at a desk. Bounder now replaces the telephone into which he has been speaking. After a pause the tourist - Mr Smoke-Too-Much - enters the office and approaches Mr Bounder's secretary.
Tourist | Good morning.
Secretary | Oh good morning. (sexily) Do you want to go upstairs?
Tourist | What?
Secretary | (sexily) Do you want to go upstairs? (brightly) Or have you come to arrange a holiday?
Tourist | Er.......to arrange a holiday.
Secretary | Oh sorry.
Tourist | What's all this about going upstairs?
Secretary | Oh, nothing, nothing. Now where were you thinking of going?
Tourist | India.
Secretary | Ah one of our adventure holidays!
Tourist | Yes!
Secretary | Well you'd better see Mr Bounder about that. Mr Bounder, this gentleman is interested in the India Overland.
| Walks over to Bounder's desk where he is greeted by Bounder.
Bounder | Ah good morning. I'm Bounder of Adventure.
Tourist | My name is Smoke-Too-Much.
Bounder | What?
Tourist | My name is Smoke-Too-Much. Mr Smoke-Too-Much.
Bounder | Well you'd better cut down a little then.
Tourist | What?
Bounder | You'd better cut down a little then.
Tourist | Oh I see! Cut down a bit, for Smoke-Too-Much.
Bounder | Yes, he he...I expect you get people making jokes about your name all the time, eh?
Tourist | No, no actually. Actually, it never struck me before. Smoke...too...much!
Bounder | Anyway, you're interested in one of our adventure holidays, eh?
Tourist | Yes. I saw your advert in the bolour supplement.
Bounder | The what?
Tourist | The bolour supplement.
Bounder | The colour supplement?
Tourist | Yes. I'm sorry I can't say the letter 'B'.
Bounder | C?
Tourist | Yes that's right. It's all due to a trauma I suffered when I was a sboolboy. I was attacked by a bat.
Bounder | A cat?
Tourist | No a bat.
Bounder | Can you say the letter 'K'?
Tourist | Oh yes, Khaki, king, kettle, Kuwait, Keble Bollege Oxford.
Bounder | Why don't you say the letter 'K' instead of the letter 'C'?
Tourist | What you mean.....spell bolour with a K?
Bounder | Yes.
Tourist | Kolour. Oh that's very good, I never thought of that.
Bounder | Anyway, about the holiday..
Tourist | Well I saw your adverts in the paper and I've been on package tours several times, you see, and I decided that this was for me.
Bounder | Ah good.
Tourist | Yes I quite agree with you, I mean what's the point of being treated like a sheep, I mean I'm fed up with going abroad and being treated like a sheep, what's the point of being carted around in buses surrounded by sweaty mindless oafs from Kettering and Boventry in their cloth caps and their cardigans and their transistor radios and their 'Sunday Mirrors', complaining about the tea, 'Oh they don't make it properly here do they not like at home' stopping at Majorcan bodegas, selling fish and chips and Watney's Red Barrel and calamares and two veg and sitting in cotton sun frocks squirting Timothy White's suncream all over their puffy raw swollen purulent flesh cos they 'overdid it on the first day'!
Bounder | (agreeing patiently) Yes. Absolutely, yes, I quite agree...
Tourist | And being herded into endless Hotel Miramars and Bellvueses and Bontinentals with their international luxury modern roomettes and their Watney's Red Barrel and their swimming pools full of fat German businessmen pretending they're acrobats and forming pyramids and frightening the children and barging in to the queues and if you're not at your table spot on seven you miss your bowl of Campbell's Cream of Mushroom soup, the first item on the menu of International Cuisine, and every Thursday night there's a bloody cabaret in the bar featuring some tiny emaciated dago with nine-inch hips and some big fat bloated tart with her hair brylcreemed down and a big arse presenting Flamenco for Foreigners.
Bounder | (beginning to get fed up) Yes, yes, now...
Tourist | And then some adenoidal typists from Birmingham with diarrhoea and flabby white legs and hairy bandy-legged wop waiters called Manuel, and then, once a week there's an excursion to the local Roman ruins where you can buy cherryade and melted ice cream and bleedin' Watney's Red Barrel, and one night they take you to a local restaurant with local colour and colouring and they show you there and you sit next to a party of people from Rhyl who keeps singing 'Torremolinos, Torremolinos' and complaining about the food - 'Oh! It's so greasy isn't it?' and then you get cornered by some drunken greengrocer from Luton with an Instamatic and Dr Scholl sandals and last Tuesday's 'Daily Express' and he drones on and on and on about how Mr. Smith should be running this country and how many languages Enoch Powell can speak and then he throws up all over the Cuba Libres.
Bounder | Will you be quiet please.
Tourist | And sending tinted postcards of places they don't know they haven't even visited, 'to all at number 22, weather wonderful, our room is marked with an "X". Wish you were here.'
Bounder | Shut up.
Tourist | 'Food very greasy but we have managed to find this marvellous little place hidden away in the back streets.'
Bounder | Shut up!
Tourist | 'Where you can even get Watney's Red Barrel and cheese and onion...'
Bounder | Shut up!!!
Tourist | '...crisps and the accordionist plays "Maybe it's because I'm a Londoner"' and spending four days on the tarmac at Luton airport on a five-day package tour with nothing to eat but dried Watney's sandwhiches....
Bounder | Shut your bloody gob! I've had enough of this, I'm going to ring the police.
| He dials and waits. Cut to a corner of a police station. One policeman is knitting, another is making a palm tree out of old newspapers. The phone rings.
Knitting Policeman | Oh...take it off the hook. (they do so)
| Cut back to travel agent's office. The man is still going on, the travel agent looks crossly at the phone and puts it down. Then picks it up and dials again.
Bounder | Hello operator, operator...I'm trying to get the police...the police yes, what? (takes off his shoe and looks inside) nine and a half, nine and a half, yes, yes...I see...well can you keep trying please...
| Through all this the tourist is still going on:
Tourist | ...and there's nowhere to sleep and the kids are vomitting and throwing up on the plastic flowers and they keep telling you it'll only be another hour although your plane is still in Iceland waiting to take some Swedes to Yugoslavia before it can pick you up on the tarmac at 3 a.m. in the bloody morning and you sit on the tarmac till six because of 'unforeseen difficulties'. i.e. the permanent strike of Air Traffic Control in Paris, and nobody can go to the lavatory until you take off at eight, and when you get to Malaga airport everybody's swallowing Enterovioform tablets and queuing for the toilets and when you finally get to the hotel, there's no water in the taps, there's no water in the pool, there's no water in the bog and there's a bleeding lizard in the bidet, and half the rooms are double-booked and you can't sleep anyway...
| The secretary comes up and looks into the camera.
Secretary | Oh! Sorry to keep you waiting...will you come this way please...
| The camera follows her as she leads us out of the office, with agent and client still rabbitting on, down a short passage to a documentary interview set where the two participants are sitting waiting. We follow her into the set.
Secretary | Here they are. (she turns to the camera again, which moves a little towards her, as if waiting to be summoned) Just here will do fine! Goodbye.
| A presenter sitting with a guest in the usual late-night line-up set.
Presenter | Good evening.
| CAPTION: 'THRUST - A QUITE CONTROVERSIAL LOOK AT THE WORLD AROUND US'
Presenter | I have with me tonight Anne Elk. Mrs Anne Elk.
Miss Elk | Miss.
| SUPERIMPOSED CAPTION: 'ANNE ELK'
Presenter | You have a new theory about the brontosaurus.
Miss Elk | Can I just say here Chris for one moment that I have a new theory about the brontosaurus.
Presenter | Exactly. (he gestures but she does not say anything) What is it?
Miss Elk | Where? (looks around)
Presenter | No, no your new theory?
Miss Elk | Oh, what is my theory?
Presenter | Yes.
Miss Elk | Oh what is my theory that it is. Yes, well you may well ask me what is my theory.
Presenter | I am asking.
Miss Elk | Good for you. My word yes. Well Chris, what is it that it is - this theory of mine. Well, this is what it is - my theory that I have, that is to say, which is mine, is mine.
Presenter | (beginning to show signs of exasperation) Yes, I know it's yours, what is it?
Miss Elk | Where? Oh, what is my theory? This is it. (clears throat at some length) My theory that belongs to me is as follows. (clears throat at great length) This is how it goes. The next thing I'm going to say is my theory. Ready?
Presenter | Yes!
Miss Elk | My Theory by A. Elk. Brackets Miss, brackets. This theory goes as follows and begins now. All brontosauruses are thin at one end, much much thicker in the middle, and then thin again at the far end. That is my theory, it is mine, and belongs to me and I own it, and what it is too.
Presenter | That's it, is it?
Miss Elk | Spot on, Chris.
Presenter | Well, er, this theory of yours seems to have hit the nail on the head.
Miss Elk | And it's mine.
Presenter | Yes, thank you for coming along to the studio. Thank you.
Miss Elk | My pleasure, Chris...
Presenter | Next week Britain's newest wasp farm...
Miss Elk | It's been a lot of fun.
Presenter | Yes, thank you very much.
Miss Elk | Saying what my theory is.
Presenter | Yes, thank you.
Miss Elk | And whose it is.
Presenter | Yes, thank you - that's all - thank you. ...opens next week.
Miss Elk | I have another theory.
Presenter | Yes.
Miss Elk | Called my second theory, or my theory number two.
Presenter | Thank you. Britain's newest wasp farm...
Miss Elk | This second theory which was the one that I had said...
Presenter | (the phone rings; he answers) Yes, no I'm trying...
Miss Elk | Which I could expound without doubt. This second theory which, with the one which I have said, forms the brace of theories which I own and which belongs to me, goes like this...
Presenter | (looking at his shoe) nine and a half, wide fitting...Balleys of Bond Street. What? No, sort of brogue.
Miss Elk | This is what it is. (clears throat)
Presenter | Eight and a half.
Miss Elk | This is it...(lots of noisy throat clearing)
| He rises and leaves the set to go next door to the travel agent set, leaving Miss Elk behind for a moment. Bounder is still on the phone. His other phone rings; he answers it.
Bounder | Hello, yes,,,yes,,,
| The presenter enters the travel set. The tourist is still droning on as before and Bounder is still on the phone.
Tourist | (carrying on all through the scene below) ...and the Spanish Tourist Board promises you that the raging cholera epidemic is merely a case of mild Spanish tummy, like the last outbreak of Spanish tummy in 1660 which killed half London and decimated Europe, and meanwhile the bloody Guardia are busy arresting sixteen-year-olds for kissing in the streets and shooting anyone under nineteen who doesn't like Franco...
| The presenter approaches Bounder.
Presenter | The fire brigade are here. They're coming.
Bounder | Hello! No, no, no I think they are all part of the British Shoe Corporation now.
| Miss Elk follows the presenter in.
Miss Elk | Chris, this other theory of mine which is mine like the other one I also own. The second theory...
| The fire brigade enter and the secretary goes to greet them. They speak to her and she takes off her shoe to check the size. Meanwhile...
Miss Elk | My second theory states that fire brigade choirs seldom sing songs about Marcel Proust.
| With only a half-beat pause the fire brigade start singing the Proust song. After the usual number of lines we hear the gong.
Voice Over | Start again.
| The loony looks into the scene on overlay and waves at the camera just as we fade to black. We hold black for a few seconds and then the loony leans in to the black and waves again before fading away.